==> Linux-PAM-0.79.tar.bz2: Linux-PAM-0.79/modules/pam_userdb/pam_userdb.h <==

#ifndef _PAM_USERSDB_H
#define _PAM_USERSDB_H
/* $Id: pam_userdb.h,v 1.2 2004/09/28 13:48:47 kukuk Exp $ */
   
/* Header files */
#include <security/pam_appl.h>

/* argument parsing */
#define PAM_DEBUG_ARG		0x0001
#define PAM_ICASE_ARG		0x0002
#define PAM_DUMP_ARG		0x0004
#define PAM_USE_AUTHTOK_ARG	0x0008
#define PAM_UNKNOWN_OK_ARG	0x0010
#define PAM_KEY_ONLY_ARG	0x0020

/* Useful macros */
#define  x_strdup(s)  ( (s) ? strdup(s):NULL )

/* The name of the module we are compiling */
#ifndef MODULE_NAME
#define MODULE_NAME	"pam_userdb"
#endif /* MODULE_NAME */

/* function prototypes */
int conversation(pam_handle_t *);

#endif /* _PAM_USERSDB_H */

/*
 * Copyright (c) Cristian Gafton <gafton@redhat.com>, 1999
 *                                              All rights reserved
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, and the entire permission notice in its entirety,
 *    including the disclaimer of warranties.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * ALTERNATIVELY, this product may be distributed under the terms of
 * the GNU Public License, in which case the provisions of the GPL are
 * required INSTEAD OF the above restrictions.  (This clause is
 * necessary due to a potential bad interaction between the GPL and
 * the restrictions contained in a BSD-style copyright.)
 *
 * THIS SOFTWARE IS PROVIDED `AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

==> Linux-PAM-1.1.5.tar.bz2: Linux-PAM-1.1.5/modules/pam_userdb/pam_userdb.h <==

#ifndef _PAM_USERSDB_H
#define _PAM_USERSDB_H
/* $Id$ */
   
/* Header files */
#include <security/pam_appl.h>

/* argument parsing */
#define PAM_DEBUG_ARG		0x0001
#define PAM_ICASE_ARG		0x0002
#define PAM_DUMP_ARG		0x0004
#define PAM_UNKNOWN_OK_ARG	0x0010
#define PAM_KEY_ONLY_ARG	0x0020
#define PAM_USE_FPASS_ARG	0x0040
#define PAM_TRY_FPASS_ARG	0x0080

/* Useful macros */
#define  x_strdup(s)  ( (s) ? strdup(s):NULL )

/* The name of the module we are compiling */
#ifndef MODULE_NAME
#define MODULE_NAME	"pam_userdb"
#endif /* MODULE_NAME */

#endif /* _PAM_USERSDB_H */

/*
 * Copyright (c) Cristian Gafton <gafton@redhat.com>, 1999
 *                                              All rights reserved
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, and the entire permission notice in its entirety,
 *    including the disclaimer of warranties.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * ALTERNATIVELY, this product may be distributed under the terms of
 * the GNU Public License, in which case the provisions of the GPL are
 * required INSTEAD OF the above restrictions.  (This clause is
 * necessary due to a potential bad interaction between the GPL and
 * the restrictions contained in a BSD-style copyright.)
 *
 * THIS SOFTWARE IS PROVIDED `AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
